pub struct LocalDatabase { /* private fields */ }Expand description
Local instance of a postgres server.
See https://www.postgresql.org/docs/16/app-postgres.html for more info.
Implementations
Sourceimpl LocalDatabase
impl LocalDatabase
Sourcepub fn new(dir: PathBuf, port: u16) -> Result<Self>
pub fn new(dir: PathBuf, port: u16) -> Result<Self>
Start a local postgres database service.
dir: The location of the on-disk postgres database. The database must already exist at
the provided path. If you instead want to create a new database see Self::new_initdb.
port: The port to listen for incoming connection on.
Sourcepub fn new_initdb(dir: PathBuf, port: u16) -> Result<Self>
pub fn new_initdb(dir: PathBuf, port: u16) -> Result<Self>
Initialize and start a local postgres database service.
Unlike Self::new, this will initialize a clean database at the provided path.