pub struct TempDb { /* private fields */ }Expand description
A temporary, local postgres database
Implementations
Sourceimpl TempDb
impl TempDb
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Create and start a new temporary postgres database.
A fresh database will be initialized in a temporary directory that will be cleand up on drop.
The running postgres service will be serving traffic on an available, os-assigned port.
pub fn database(&self) -> &LocalDatabase
pub fn database_mut(&mut self) -> &mut LocalDatabase
pub fn dir(&self) -> &Path